==> 0.0.36.tar.gz: lib/src/models/story.dart <==
import 'dart:convert';

import 'package:equatable/equatable.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:ocg_user/ocg_user.dart';

part 'story.g.dart';

class StoryType {
  static String get image => "image";
  static String get video => "video";
  static String get quiz => "quiz";
  static String get quizList => "quizList";
}

class Story extends Equatable {
  final String id;
  final String userId;
  final DateTime createdAt;
  final StoryBackground background;
  final StoryData data;
  final User user;
  final List<String> seenBy;

  Story(
    this.id,
    this.userId,
    this.createdAt,
    this.background,
    this.data,
    this.seenBy,
  ) : this.user = null;

  Story.named({
    this.id,
    this.userId,
    this.user,
    this.createdAt,
    this.background,
    this.data,
    this.seenBy,
  });

  copyWith(
      {String id,
      StoryData data,
      DateTime createdAt,
      User user,
      List<String> seenBy,
      String userId}) {
    return Story.named(
        id: id ?? this.id,
        data: data ?? this.data,
        user: user ?? this.user,
        userId: userId ?? this.userId,
        background: background ?? this.background,
        createdAt: createdAt ?? this.createdAt,
        seenBy: seenBy ?? this.seenBy);
  }

  @override
  List<Object> get props => [id];

  Map<String, dynamic> toJson() {
    return {
      "story_id": id,
      "background": jsonEncode(background is StoryImage
          ? (background as StoryImage).toJson()
          : background is StoryVideo
              ? (background as StoryVideo).toJson()
              : {}),
      'data': jsonEncode({}),
      'createdAt': createdAt?.toIso8601String(),
      'user': user?.toJson(),
      'user_id': user?.id,
      'seen_by': seenBy ?? []
    };
  }

  factory Story.fromJson(json) {
    return Story.named(
        id: json["story_id"],
        background: json["background"] != null
            ? json["background"]["type"] == StoryType.image
                ? StoryImage.fromJson(json["background"])
                : json["background"]["type"] == StoryType.video
                    ? StoryVideo.fromJson(json["background"])
                    : null
            : null,
        createdAt: DateTime.tryParse("${json["created_at"]}"),
        seenBy: List<String>.from(json["seen_by"] ?? []),
        userId: json["user_id"],
        data: null, // TODO
        user: json["user"] != null ? User.fromJson(json["user"]) : null);
  }
}

@JsonSerializable(explicitToJson: true)
class StoryUser {
  final String id;
  final String name;
  final String profilePic;

  StoryUser(this.id, this.name, this.profilePic);
  StoryUser.named({this.id, this.name, this.profilePic});

  Map<String, dynamic> toJson() => _$StoryUserToJson(this);

  factory StoryUser.fromJson(json) => _$StoryUserFromJson(json);
}

abstract class StoryBackground {
  final String type;

  StoryBackground(
    this.type,
  );
}

@JsonSerializable(explicitToJson: true)
class StoryVideo extends StoryBackground {
  final String url;
  final String thumbnail;

  StoryVideo(this.url, this.thumbnail) : super(StoryType.video);

  StoryVideo.named({this.url, this.thumbnail}) : super(StoryType.video);

  Map<String, dynamic> toJson() {
    var json = _$StoryVideoToJson(this);
    json["type"] = StoryType.video;
    return json;
  }

  factory StoryVideo.fromJson(json) => _$StoryVideoFromJson(json);
}

@JsonSerializable(explicitToJson: true)
class StoryImage extends StoryBackground {
  final String url;

  StoryImage(this.url) : super(StoryType.image);

  StoryImage.named({this.url}) : super(StoryType.image);

  Map<String, dynamic> toJson() {
    var json = _$StoryImageToJson(this);
    json["type"] = StoryType.image;
    return json;
  }

  factory StoryImage.fromJson(json) => _$StoryImageFromJson(json);
}

abstract class StoryData {
  final String type;

  StoryData(
    this.type,
  );
}

==> 0.0.47.tar.gz: lib/src/models/story.dart <==
import 'dart:convert';

import 'package:equatable/equatable.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:ocg_user/ocg_user.dart';

part 'story.g.dart';

class StoryType {
  static String get image => "image";
  static String get video => "video";
  static String get quiz => "quiz";
  static String get quizList => "quizList";
}

class Story extends Equatable {
  final String id;
  final String userId;
  final DateTime createdAt;
  final StoryBackground background;
  final StoryData data;
  final User user;
  final List<String> seenBy;
  final bool isSeen;
  final bool isSelf;

  Story(
    this.id,
    this.userId,
    this.createdAt,
    this.background,
    this.data,
    this.seenBy,
  )   : this.user = null,
        this.isSeen = false,
        this.isSelf = false;

  Story.named(
      {this.id,
      this.userId,
      this.user,
      this.createdAt,
      this.background,
      this.data,
      this.seenBy,
      this.isSeen,
      this.isSelf});

  copyWith(
      {String id,
      StoryData data,
      DateTime createdAt,
      User user,
      List<String> seenBy,
      String userId,
      bool isSeen,
      bool isSelf}) {
    return Story.named(
        id: id ?? this.id,
        data: data ?? this.data,
        user: user ?? this.user,
        userId: userId ?? this.userId,
        background: background ?? this.background,
        createdAt: createdAt ?? this.createdAt,
        seenBy: seenBy ?? this.seenBy,
        isSeen: isSeen ?? this.isSeen,
        isSelf: isSelf ?? this.isSelf);
  }

  @override
  List<Object> get props => [id];

  Map<String, dynamic> toJson() {
    return {
      "story_id": id,
      "background": jsonEncode(background is StoryImage
          ? (background as StoryImage).toJson()
          : background is StoryVideo
              ? (background as StoryVideo).toJson()
              : {}),
      'data': jsonEncode({}),
      'createdAt': createdAt?.toIso8601String(),
      'user': user?.toJson(),
      'user_id': user?.id,
      'seen_by': seenBy ?? []
    };
  }

  factory Story.fromJson(json) {
    return Story.named(
        id: json["story_id"],
        background: json["background"] != null
            ? json["background"]["type"] == StoryType.image
                ? StoryImage.fromJson(json["background"])
                : json["background"]["type"] == StoryType.video
                    ? StoryVideo.fromJson(json["background"])
                    : null
            : null,
        createdAt: DateTime.tryParse("${json["created_at"]}"),
        seenBy: List<String>.from(json["seen_by"] ?? []),
        userId: json["user_id"],
        data: null, // TODO
        user: json["user"] != null ? User.fromJson(json["user"]) : null);
  }
}

@JsonSerializable(explicitToJson: true)
class StoryUser {
  final String id;
  final String name;
  final String profilePic;

  StoryUser(this.id, this.name, this.profilePic);
  StoryUser.named({this.id, this.name, this.profilePic});

  Map<String, dynamic> toJson() => _$StoryUserToJson(this);

  factory StoryUser.fromJson(json) => _$StoryUserFromJson(json);
}

abstract class StoryBackground {
  final String type;

  StoryBackground(
    this.type,
  );
}

@JsonSerializable(explicitToJson: true)
class StoryVideo extends StoryBackground {
  final String url;
  final String thumbnail;

  StoryVideo(this.url, this.thumbnail) : super(StoryType.video);

  StoryVideo.named({this.url, this.thumbnail}) : super(StoryType.video);

  Map<String, dynamic> toJson() {
    var json = _$StoryVideoToJson(this);
    json["type"] = StoryType.video;
    return json;
  }

  factory StoryVideo.fromJson(json) => _$StoryVideoFromJson(json);
}

@JsonSerializable(explicitToJson: true)
class StoryImage extends StoryBackground {
  final String url;

  StoryImage(this.url) : super(StoryType.image);

  StoryImage.named({this.url}) : super(StoryType.image);

  Map<String, dynamic> toJson() {
    var json = _$StoryImageToJson(this);
    json["type"] = StoryType.image;
    return json;
  }

  factory StoryImage.fromJson(json) => _$StoryImageFromJson(json);
}

abstract class StoryData {
  final String type;

  StoryData(
    this.type,
  );
}
